# OPS02-BP02: Processes and procedures have identified owners

## Description

Mỗi process cần có người chịu trách nhiệm.

## Implementation Guidance

- Document all operational processes
- Assign owners to each process
- Define review cadence for processes
- Track process changes and updates
- Ensure owners have authority to make changes

## Risk Level

Medium - Unowned processes become outdated and ineffective.
